@@ -24,7 +24,7 @@ class SearchableSnapshotsClient(NamespacedClient):
         """
         Clear the cache of searchable snapshots.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/searchable-snapshots-apis.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/searchable-snapshots-apis.html>`_
 
         .. warning::
 
@@ -54,7 +54,7 @@ class SearchableSnapshotsClient(NamespacedClient):
         """
         Mount a snapshot as a searchable index.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/searchable-snapshots-api-mount-snapshot.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/searchable-snapshots-api-mount-snapshot.html>`_
 
         .. warning::
 
@@ -90,7 +90,7 @@ class SearchableSnapshotsClient(NamespacedClient):
         """
         DEPRECATED: This API is replaced by the Repositories Metering API.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/searchable-snapshots-apis.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/searchable-snapshots-apis.html>`_
 
         .. warning::
 
@@ -112,9 +112,9 @@ class SearchableSnapshotsClient(NamespacedClient):
     @query_params("level")
     async def stats(self, index=None, params=None, headers=None):
         """
-        Retrieve various statistics about searchable snapshots.
+        Retrieve shard-level statistics about searchable snapshots.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/searchable-snapshots-apis.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/searchable-snapshots-apis.html>`_
 
         .. warning::
 
@@ -131,3 +131,27 @@ class SearchableSnapshotsClient(NamespacedClient):
             params=params,
             headers=headers,
         )
+
+    @query_params()
+    async def cache_stats(self, node_id=None, params=None, headers=None):
+        """
+        Retrieve node-level cache statistics about searchable snapshots.
+
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/searchable-snapshots-apis.html>`_
+
+        .. warning::
+
+            This API is **experimental** so may include breaking changes
+            or be removed in a future version
+
+        :arg node_id: A comma-separated list of node IDs or names to
+            limit the returned information; use `_local` to return information from
+            the node you're connecting to, leave empty to get information from all
+            nodes
+        """
+        return await self.transport.perform_request(
+            "GET",
+            _make_path("_searchable_snapshots", node_id, "cache", "stats"),
+            params=params,
+            headers=headers,
+        )
