@@ -16,25 +16,23 @@
 #  under the License.
 
 import asyncio
-import ssl
 import os
-import urllib3
+import ssl
 import warnings
 
-import aiohttp
-import yarl
-from aiohttp.client_exceptions import ServerFingerprintMismatch, ServerTimeoutError
+import urllib3  # type: ignore
 
-from .compat import get_running_loop
-from ..connection import Connection
 from ..compat import urlencode
+from ..connection.base import Connection
 from ..exceptions import (
     ConnectionError,
     ConnectionTimeout,
     ImproperlyConfigured,
     SSLError,
 )
-
+from ..utils import _client_meta_version
+from ._extra_imports import aiohttp, aiohttp_exceptions, yarl
+from .compat import get_running_loop
 
 # sentinel value for `verify_certs`.
 # This is used to detect if a user is passing in a value
@@ -52,7 +50,29 @@ except ImportError:
     pass
 
 
-class AIOHttpConnection(Connection):
+class AsyncConnection(Connection):
+    """Base class for Async HTTP connection implementations"""
+
+    async def perform_request(
+        self,
+        method,
+        url,
+        params=None,
+        body=None,
+        timeout=None,
+        ignore=(),
+        headers=None,
+    ):
+        raise NotImplementedError()
+
+    async def close(self):
+        raise NotImplementedError()
+
+
+class AIOHttpConnection(AsyncConnection):
+
+    HTTP_CLIENT_META = ("ai", _client_meta_version(aiohttp.__version__))
+
     def __init__(
         self,
         host="localhost",
@@ -81,6 +101,7 @@ class AIOHttpConnection(Connection):
 
         :arg host: hostname of the node (default: localhost)
         :arg port: port to use (integer, default: 9200)
+        :arg url_prefix: optional url prefix for elasticsearch
         :arg timeout: default timeout in seconds (float, default: 10)
         :arg http_auth: optional http auth information as either ':' separated
             string or a tuple
@@ -184,6 +205,16 @@ class AIOHttpConnection(Connection):
             else:
                 raise ImproperlyConfigured("ca_certs parameter is not a path")
 
+            # Use client_cert and client_key variables for SSL certificate configuration.
+            if client_cert and not os.path.isfile(client_cert):
+                raise ImproperlyConfigured("client_cert is not a path to a file")
+            if client_key and not os.path.isfile(client_key):
+                raise ImproperlyConfigured("client_key is not a path to a file")
+            if client_cert and client_key:
+                ssl_context.load_cert_chain(client_cert, client_key)
+            elif client_cert:
+                ssl_context.load_cert_chain(client_cert)
+
         self.headers.setdefault("connection", "keep-alive")
         self.loop = loop
         self.session = None
@@ -198,9 +229,10 @@ class AIOHttpConnection(Connection):
     ):
         if self.session is None:
             await self._create_aiohttp_session()
+        assert self.session is not None
 
         orig_body = body
-        url_path = url
+        url_path = self.url_prefix + url
         if params:
             query_string = urlencode(params)
         else:
@@ -214,15 +246,30 @@ class AIOHttpConnection(Connection):
             method = "GET"
             is_head = True
 
-        # Provide correct URL object to avoid string parsing in low-level code
-        url = yarl.URL.build(
-            scheme=self.scheme,
-            host=self.hostname,
-            port=self.port,
-            path=url,
-            query_string=query_string,
-            encoded=True,
-        )
+        # Top-tier tip-toeing happening here. Basically
+        # because Pip's old resolver is bad and wipes out
+        # strict pins in favor of non-strict pins of extras
+        # our [async] extra overrides aiohttp's pin of
+        # yarl. yarl released breaking changes, aiohttp pinned
+        # defensively afterwards, but our users don't get
+        # that nice pin that aiohttp set. :( So to play around
+        # this super-defensively we try to import yarl, if we can't
+        # then we pass a string into ClientSession.request() instead.
+        if yarl:
+            # Provide correct URL object to avoid string parsing in low-level code
+            url = yarl.URL.build(
+                scheme=self.scheme,
+                host=self.hostname,
+                port=self.port,
+                path=url_path,
+                query_string=query_string,
+                encoded=True,
+            )
+        else:
+            url = self.url_prefix + url
+            if query_string:
+                url = "%s?%s" % (url, query_string)
+            url = self.host + url
 
         timeout = aiohttp.ClientTimeout(
             total=timeout if timeout is not None else self.timeout
@@ -259,11 +306,18 @@ class AIOHttpConnection(Connection):
 
         except Exception as e:
             self.log_request_fail(
-                method, url, url_path, orig_body, self.loop.time() - start, exception=e
+                method,
+                str(url),
+                url_path,
+                orig_body,
+                self.loop.time() - start,
+                exception=e,
             )
-            if isinstance(e, ServerFingerprintMismatch):
+            if isinstance(e, aiohttp_exceptions.ServerFingerprintMismatch):
                 raise SSLError("N/A", str(e), e)
-            if isinstance(e, (asyncio.TimeoutError, ServerTimeoutError)):
+            if isinstance(
+                e, (asyncio.TimeoutError, aiohttp_exceptions.ServerTimeoutError)
+            ):
                 raise ConnectionTimeout("TIMEOUT", str(e), e)
             raise ConnectionError("N/A", str(e), e)
 
@@ -275,7 +329,7 @@ class AIOHttpConnection(Connection):
         if not (200 <= response.status < 300) and response.status not in ignore:
             self.log_request_fail(
                 method,
-                url,
+                str(url),
                 url_path,
                 orig_body,
                 duration,
@@ -285,7 +339,7 @@ class AIOHttpConnection(Connection):
             self._raise_error(response.status, raw_data)
 
         self.log_request_success(
-            method, url, url_path, orig_body, response.status, raw_data, duration
+            method, str(url), url_path, orig_body, response.status, raw_data, duration
         )
 
         return response.status, response.headers, raw_data
@@ -311,7 +365,7 @@ class AIOHttpConnection(Connection):
             cookie_jar=aiohttp.DummyCookieJar(),
             response_class=ESClientResponse,
             connector=aiohttp.TCPConnector(
-                limit=self._limit, use_dns_cache=True, ssl=self._ssl_context,
+                limit=self._limit, use_dns_cache=True, ssl=self._ssl_context
             ),
         )
 
