@@ -24,7 +24,7 @@ class RollupClient(NamespacedClient):
         """
         Deletes an existing rollup job.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/rollup-delete-job.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/rollup-delete-job.html>`_
 
         .. warning::
 
@@ -45,7 +45,7 @@ class RollupClient(NamespacedClient):
         """
         Retrieves the configuration, stats, and status of rollup jobs.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/rollup-get-job.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/rollup-get-job.html>`_
 
         .. warning::
 
@@ -65,7 +65,7 @@ class RollupClient(NamespacedClient):
         Returns the capabilities of any rollup jobs that have been configured for a
         specific index or index pattern.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/rollup-get-rollup-caps.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/rollup-get-rollup-caps.html>`_
 
         .. warning::
 
@@ -85,7 +85,7 @@ class RollupClient(NamespacedClient):
         Returns the rollup capabilities of all jobs inside of a rollup index (e.g. the
         index where rollup data is stored).
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/rollup-get-rollup-index-caps.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/rollup-get-rollup-index-caps.html>`_
 
         .. warning::
 
@@ -107,7 +107,7 @@ class RollupClient(NamespacedClient):
         """
         Creates a rollup job.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/rollup-put-job.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/rollup-put-job.html>`_
 
         .. warning::
 
@@ -134,7 +134,7 @@ class RollupClient(NamespacedClient):
         """
         Enables searching rolled-up data using the standard query DSL.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/rollup-search.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/rollup-search.html>`_
 
         .. warning::
 
@@ -167,7 +167,7 @@ class RollupClient(NamespacedClient):
         """
         Starts an existing, stopped rollup job.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/rollup-start-job.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/rollup-start-job.html>`_
 
         .. warning::
 
@@ -191,7 +191,7 @@ class RollupClient(NamespacedClient):
         """
         Stops an existing, started rollup job.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/rollup-stop-job.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/rollup-stop-job.html>`_
 
         .. warning::
 
@@ -220,7 +220,7 @@ class RollupClient(NamespacedClient):
         """
         Rollup an index
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/master/rollup-api.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/rollup-api.html>`_
 
         :arg index: The index to roll up
         :arg rollup_index: The name of the rollup index to create
