@@ -15,7 +15,7 @@
 #  specific language governing permissions and limitations
 #  under the License.
 
-from .utils import NamespacedClient, query_params, _make_path, SKIP_IN_PATH
+from .utils import SKIP_IN_PATH, NamespacedClient, _make_path, query_params
 
 
 class TransformClient(NamespacedClient):
@@ -24,7 +24,7 @@ class TransformClient(NamespacedClient):
         """
         Deletes an existing transform.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/delete-transform.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/delete-transform.html>`_
 
         :arg transform_id: The id of the transform to delete
         :arg force: When `true`, the transform is deleted regardless of
@@ -48,7 +48,7 @@ class TransformClient(NamespacedClient):
         """
         Retrieves configuration information for transforms.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/get-transform.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/get-transform.html>`_
 
         :arg transform_id: The id or comma delimited list of id
             expressions of the transforms to get, '_all' or '*' implies get all
@@ -78,7 +78,7 @@ class TransformClient(NamespacedClient):
         """
         Retrieves usage information for transforms.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/get-transform-stats.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/get-transform-stats.html>`_
 
         :arg transform_id: The id of the transform for which to get
             stats. '_all' or '*' implies all transforms
@@ -110,7 +110,7 @@ class TransformClient(NamespacedClient):
         """
         Previews a transform.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/preview-transform.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/preview-transform.html>`_
 
         :arg body: The definition for the transform to preview
         """
@@ -126,7 +126,7 @@ class TransformClient(NamespacedClient):
         """
         Instantiates a transform.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/put-transform.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/put-transform.html>`_
 
         :arg transform_id: The id of the new transform.
         :arg body: The transform definition
@@ -150,7 +150,7 @@ class TransformClient(NamespacedClient):
         """
         Starts one or more transforms.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/start-transform.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/start-transform.html>`_
 
         :arg transform_id: The id of the transform to start
         :arg timeout: Controls the time to wait for the transform to
@@ -179,7 +179,7 @@ class TransformClient(NamespacedClient):
         """
         Stops one or more transforms.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/stop-transform.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/stop-transform.html>`_
 
         :arg transform_id: The id of the transform to stop
         :arg allow_no_match: Whether to ignore if a wildcard expression
@@ -211,7 +211,7 @@ class TransformClient(NamespacedClient):
         """
         Updates certain properties of a transform.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/update-transform.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/update-transform.html>`_
 
         :arg transform_id: The id of the transform.
         :arg body: The update transform definition
